@@ -23,13 +23,13 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
+#include <glib-unix.h>
 
 #include <signal.h>
 #include <gio/gio.h>
 
 #include <goabackend/goabackend.h>
 
-#include "gposixsignal.h"
 #include "goadaemon.h"
 
 
@@ -38,10 +38,12 @@
 static GMainLoop *loop = NULL;
 static gboolean opt_replace = FALSE;
 static gboolean opt_no_sigint = FALSE;
+static gboolean opt_no_color = FALSE;
 static GOptionEntry opt_entries[] =
 {
   {"replace", 0, 0, G_OPTION_ARG_NONE, &opt_replace, "Replace existing daemon", NULL},
   {"no-sigint", 0, 0, G_OPTION_ARG_NONE, &opt_no_sigint, "Do not handle SIGINT for controlled shutdown", NULL},
+  {"no-color", 0, 0, G_OPTION_ARG_NONE, &opt_no_color, "Do not display colors in output", NULL},
   {NULL }
 };
 static GoaDaemon *the_daemon = NULL;
@@ -107,6 +109,7 @@ main (int    argc,
       goto out;
     }
 
+  goa_log_init (opt_no_color);
   goa_notice ("goa-daemon version %s starting", PACKAGE_VERSION);
 
   loop = g_main_loop_new (NULL, FALSE);
@@ -114,11 +117,7 @@ main (int    argc,
   sigint_id = 0;
   if (!opt_no_sigint)
     {
-      sigint_id = _g_posix_signal_watch_add (SIGINT,
-                                             G_PRIORITY_DEFAULT,
-                                             on_sigint,
-                                             NULL,
-                                             NULL);
+      sigint_id = g_unix_signal_add (SIGINT, on_sigint, NULL);
     }
 
   name_owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
