@@ -79,6 +79,12 @@ get_provider_name (GoaProvider *_provider,
   return g_strdup (_("Facebook"));
 }
 
+static GoaProviderGroup
+get_provider_group (GoaProvider *_provider)
+{
+  return GOA_PROVIDER_GROUP_BRANDED;
+}
+
 /* facebook client flow sends a different auth query then the base
  * OAuth2Provider */
 static gchar *
@@ -416,6 +422,7 @@ goa_facebook_provider_class_init (GoaFacebookProviderClass *klass)
   provider_class = GOA_PROVIDER_CLASS (klass);
   provider_class->get_provider_type          = get_provider_type;
   provider_class->get_provider_name          = get_provider_name;
+  provider_class->get_provider_group         = get_provider_group;
   provider_class->build_object               = build_object;
   provider_class->show_account               = show_account;
 
