@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012 Red Hat, Inc.
+ * Copyright (C) 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -118,6 +118,7 @@ goa_utils_delete_credentials_sync (GoaProvider   *provider,
   gboolean ret;
   gchar *password_key;
   const gchar *identity;
+  GError *sec_error = NULL;
 
   g_return_val_if_fail (GOA_IS_PROVIDER (provider), FALSE);
   g_return_val_if_fail (GOA_IS_ACCOUNT (object), FALSE);
@@ -135,19 +136,23 @@ goa_utils_delete_credentials_sync (GoaProvider   *provider,
                                   goa_provider_get_credentials_generation (GOA_PROVIDER (provider)),
                                   identity);
 
-  if (!secret_password_clear_sync (&secret_password_schema,
-                                   cancellable,
-                                   NULL,
-                                   "goa-identity", password_key,
-                                   NULL))
+  secret_password_clear_sync (&secret_password_schema,
+                              cancellable,
+                              &sec_error,
+                              "goa-identity", password_key,
+                              NULL);
+  if (sec_error != NULL)
     {
+      goa_warning ("secret_password_clear_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
                            _("Failed to delete credentials from the keyring"));
+      g_error_free (sec_error);
       goto out;
     }
 
+  goa_debug ("Cleared keyring credentials for identity: %s", identity);
   ret = TRUE;
 
  out:
@@ -165,6 +170,7 @@ goa_utils_lookup_credentials_sync (GoaProvider   *provider,
   GVariant *ret;
   gchar *password;
   const gchar *identity;
+  GError *sec_error = NULL;
 
   g_return_val_if_fail (GOA_IS_PROVIDER (provider), NULL);
   g_return_val_if_fail (GOA_IS_OBJECT (object) && goa_object_peek_account (object) != NULL, FALSE);
@@ -184,17 +190,30 @@ goa_utils_lookup_credentials_sync (GoaProvider   *provider,
 
   password = secret_password_lookup_sync (&secret_password_schema,
                                           cancellable,
-                                          NULL,
+                                          &sec_error,
                                           "goa-identity", password_key,
                                           NULL);
-  if (password == NULL)
+  if (sec_error != NULL)
     {
+      goa_warning ("secret_password_lookup_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
                            _("Failed to retrieve credentials from the keyring"));
+      g_error_free (sec_error);
       goto out;
     }
+  else if (password == NULL)
+    {
+      goa_warning ("secret_password_lookup_sync() returned NULL");
+      g_set_error_literal (error,
+                           GOA_ERROR,
+                           GOA_ERROR_FAILED, /* TODO: more specific */
+                           _("No credentials found in the keyring"));
+      goto out;
+    }
+
+  goa_debug ("Retreived keyring credentials for identity: %s", identity);
 
   ret = g_variant_parse (NULL, /* GVariantType */
                          password,
@@ -227,6 +246,7 @@ goa_utils_store_credentials_for_id_sync (GoaProvider   *provider,
   gchar *credentials_str;
   gchar *password_description;
   gchar *password_key;
+  GError *sec_error = NULL;
 
   g_return_val_if_fail (GOA_IS_PROVIDER (provider), FALSE);
   g_return_val_if_fail (id != NULL && id[0] != '\0', FALSE);
@@ -254,17 +274,20 @@ goa_utils_store_credentials_for_id_sync (GoaProvider   *provider,
                                    password_description,
                                    credentials_str,
                                    cancellable,
-                                   NULL,
+                                   &sec_error,
                                    "goa-identity", password_key,
                                    NULL))
     {
+      goa_warning ("secret_password_store_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
                            _("Failed to store credentials in the keyring"));
+      g_error_free (sec_error);
       goto out;
     }
 
+  goa_debug ("Stored keyring credentials for identity: %s", id);
   ret = TRUE;
 
  out:
@@ -442,3 +465,43 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
   g_free (group);
   g_free (path);
 }
+
+void
+goa_utils_set_error_ssl (GError **err, GTlsCertificateFlags flags)
+{
+  const gchar *error_msg;
+
+  switch (flags)
+    {
+    case G_TLS_CERTIFICATE_UNKNOWN_CA:
+      error_msg = _("The signing certificate authority is not known.");
+      break;
+
+    case G_TLS_CERTIFICATE_BAD_IDENTITY:
+      error_msg = _("The certificate does not match the expected identity of the site that it was "
+                    "retrieved from.");
+      break;
+
+    case G_TLS_CERTIFICATE_NOT_ACTIVATED:
+      error_msg = _("The certificate's activation time is still in the future.");
+      break;
+
+    case G_TLS_CERTIFICATE_EXPIRED:
+      error_msg = _("The certificate has expired.");
+      break;
+
+    case G_TLS_CERTIFICATE_REVOKED:
+      error_msg = _("The certificate has been revoked.");
+      break;
+
+    case G_TLS_CERTIFICATE_INSECURE:
+      error_msg = _("The certificate's algorithm is considered insecure.");
+      break;
+
+    default:
+      error_msg = _("Invalid certificate.");
+      break;
+    }
+
+  g_set_error_literal (err, GOA_ERROR, GOA_ERROR_SSL, error_msg);
+}
